@@ -576,23 +576,24 @@
 ;; @end example
 ;; @end deffn
 (define* (expand-cpp-macro-ref ident defs #:optional (used '()))
-  ;;(sferr "x-mref ~S  used=~S\n" ident used)
   (let ((rval (assoc-ref defs ident)))
     (cond
      ((member ident used) #f)
      ((string? rval)
       (let* ((used (cons ident used))
 	     (repl (cpp-expand-text rval defs used)))
-	;;(sferr "rerun ~S => ~S\n" repl (ident-like? repl))
 	(if (ident-like? repl)
-	    ;; between 0.80.4 and 0.82.1 I had (cons repl used)
 	    (or (expand-cpp-macro-ref repl defs used) repl)
 	    repl)))
      ((pair? rval)
       (and=> (collect-args (car rval) defs used)
 	     (lambda (argd)
-	       (let ((rez (px-cpp-ftn argd (cdr rval))))
-		 (cpp-expand-text rez defs (cons ident used))))))
+	       (let* ((used (cons ident used))
+		      (prep (px-cpp-ftn argd (cdr rval)))
+		      (repl (cpp-expand-text prep defs used)))
+		 (if (ident-like? repl)
+		     (or (expand-cpp-macro-ref repl defs used) repl)
+		     repl)))))
      ((c99-std-val ident) => identity)
      (else #f))))
 
